flownetpy.flowmodel package
===========================

Submodules
----------

flownetpy.flowmodel.kuramoto module
-----------------------------------

.. automodule:: flownetpy.flowmodel.kuramoto
    :members:
    :undoc-members:
    :show-inheritance:

flownetpy.flowmodel.linear module
---------------------------------

.. automodule:: flownetpy.flowmodel.linear
    :members:
    :undoc-members:
    :show-inheritance:

flownetpy.flowmodel.tools module
--------------------------------

.. automodule:: flownetpy.flowmodel.tools
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: flownetpy.flowmodel
    :members:
    :undoc-members:
    :show-inheritance:
